@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: kronolith/day.php,v 1.33 2001/11/05 16:02:32 chuck Exp $
+ * $Horde: kronolith/day.php,v 1.36.2.1 2002/03/19 02:10:40 chuck Exp $
  *
  * Copyright 1999, 2000 Charles J. Hagenbuch <chuck@horde.org>
  *
@@ -18,21 +18,17 @@ $year = Horde::getFormData('year');
 $timestamp = Horde::getFormData('timestamp');
 $dayOb = new Kronolith_DayView($month, $day, $year, $timestamp);
 $title = $dayOb->Day->getTime($prefs->getValue('date_format'));
+$js_onLoad = null;
 
 if ($conf['compress_pages']) {
-    include_once 'HTTP/Compress.php';
-    HTTP_Compress::start();
+    ob_start('ob_gzhandler');
 }
 
-require $registry->getTemplatePath() . '/common-header.inc';
+require KRONOLITH_TEMPLATES . '/common-header.inc';
 require './menu.php';
 
-$dayOb->html($registry->getTemplatePath());
+$dayOb->html(KRONOLITH_TEMPLATES);
 
-require $registry->getTemplatePath() . '/common-footer.inc';
-
-if ($conf['compress_pages']) {
-    HTTP_Compress::output();
-}
+require KRONOLITH_TEMPLATES . '/common-footer.inc';
 
 ?>
