@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: kronolith/editevent.php,v 1.26 2001/07/17 20:07:57 jan Exp $
+ * $Horde: kronolith/editevent.php,v 1.27.2.2 2002/04/23 17:59:48 chuck Exp $
  *
  * Copyright 1999, 2000 Charles J. Hagenbuch <chuck@horde.org>
  *
@@ -23,12 +23,13 @@ if ($timestamp = Horde::getFormData('timestamp')) {
 
 $url = Horde::getFormData('url');
 
-$title = _("Edit ") . $event->getTitle();
+$title = sprintf(_("Edit %s"), $event->getTitle());
+$js_onLoad = null;
 
-require $registry->getTemplatePath() . '/common-header.inc';
-require './menu.php';
-require $registry->getTemplatePath() . '/edit/javascript.inc';
-require $registry->getTemplatePath() . '/edit/edit.inc';
-require $registry->getTemplatePath() . '/common-footer.inc';
+require KRONOLITH_TEMPLATES . '/common-header.inc';
+require KRONOLITH_BASE . '/menu.php';
+require KRONOLITH_TEMPLATES . '/edit/javascript.inc';
+require KRONOLITH_TEMPLATES . '/edit/edit.inc';
+require KRONOLITH_TEMPLATES . '/common-footer.inc';
 
 ?>
