@@ -1,11 +1,11 @@
 <?php
-// $Horde: kronolith/lib/Day.php,v 1.15 2001/09/18 16:03:51 jan Exp $
+// $Horde: kronolith/lib/Day.php,v 1.16 2002/01/25 05:51:06 chuck Exp $
 
 /**
  * The Kronolith_Day:: class provides an API for dealing with days.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.15 $
+ * @version $Revision: 1.16 $
  * @since   Kronolith 0.1
  * @package kronolith
  */
@@ -17,25 +17,23 @@ class Kronolith_Day {
     var $time;
     var $hours;
     
-    
-    function Kronolith_Day ($month = null, $day = null, $year = null, $timestamp = null) {
+    function Kronolith_Day($month = null, $day = null, $year = null, $timestamp = null)
+    {
         if (!empty($timestamp)) {
             $this->time = $timestamp;
         } else {
             if (!isset($month)) {
                 $month = date('m');
             }
-            
             if (!isset($year)) {
                 $year = date('Y');
             }
-            
             if (!isset($day)) {
                 $day = date('d');
             }
             
             // now, compensate for any wrap around
-            $this->time = mktime(0,0,0,$month,$day,$year);
+            $this->time = mktime(0, 0, 0, $month, $day, $year);
         }
         
         $this->month = date('m', $this->time);
@@ -47,7 +45,8 @@ class Kronolith_Day {
     }
   
   
-    function makeHours () {
+    function makeHours()
+    {
         $this->hours = array();
     
         $row = 0;
